Function embedded_profiling::log_snapshot [−][src]
pub fn log_snapshot(snapshot: &EPSnapshot)Expand description
Logs the given snapshot with the globally configured profiler
pub fn log_snapshot(snapshot: &EPSnapshot)Logs the given snapshot with the globally configured profiler